@@ -34,8 +34,8 @@ class RadiometricCalibSession(CalibrationSession, ABC):
                 os.mkdir('CalibrationNumpyData')
             os.mkdir('CalibrationNumpyData/Radiometric/')
         if not os.path.exists('CapturedNumpyData/Radiometric/'):
-            if not os.path.exists('CalibrationNumpyData'):
-                os.mkdir('CalibrationNumpyData')
+            if not os.path.exists('CapturedNumpyData'):
+                os.mkdir('CapturedNumpyData')
             os.mkdir('CapturedNumpyData/Radiometric/')
             
         for exp in self.exposures:
